@@ -12,11 +12,10 @@ from tank_forecaster.decomp import (
 
 def gen_future(df, periods=30, freq="1D"):
     start_0 = df.iloc[-1, 0]
-    future = pd.date_range(start=start_0, freq=freq, periods=periods) + pd.Timedelta(
-        freq
-    )
+    future = pd.date_range(start=start_0, freq=freq, periods=periods) + pd.Timedelta(freq)
     future = pd.DataFrame(future)
     future.rename(columns={0: "ds"}, inplace=True)
+
     return future
 
 
@@ -27,19 +26,20 @@ def forecast_far(
     forecast_length=90,
     daily_lift_est=0,
 ):
-
-    if yearly_decomp is None:
+    # if no decompositions are created, or not a full year of sales data, use generic
+    if yearly_decomp is None or len(yearly_decomp) <= 52:
         yearly_decomp = generic_yearly_decomp
-    if weekly_decomp is None:
+
+    if weekly_decomp is None or len(weekly_decomp) <= 6:
         weekly_decomp = generic_weekly_decomp
 
-    # generate predictions
+    # generate predictions DataFrame
     predictions = pd.DataFrame(columns=["woy", "dow", "base", "weekly", "daily"])
     predictions["woy"] = np.repeat(range(1, 54), 7)  # 52.14 'week of year' -> 53
     predictions["dow"] = [0, 1, 2, 3, 4, 5, 6] * 53  # 7 'day of week' each week of year
 
-    # no historical data
-    if type(sales_history) != pd.core.frame.DataFrame:
+    # if no sales data is given, use daily_lift_estimate input w/ generic seasonality
+    if sales_history is None or len(sales_history) == 0:
         predictions["base"] = daily_lift_est
         weekly = np.repeat(predictions.base.iloc[1] * 7 * generic_yearly_decomp, 7)
         weekly.index = range(0, 371)
@@ -52,22 +52,18 @@ def forecast_far(
         }
         sales_history = pd.DataFrame(data=data)
         sales_history["date"] = sales_history["ds"].dt.date
-    else:
+
+    else:  # if full year or more of sales data, use last year's average
         predictions["base"] = sales_history.y[-365:].mean()
 
-    if (
-        len(yearly_decomp) <= 52
-    ):  # less than 1 year sales data, use generic yearly trends
-        weekly = np.repeat(predictions.base[1] * 7 * generic_yearly_decomp, 7)
-    else:  # more than 1 year sales data, use tank specific yearly trends
-        weekly = np.repeat(predictions.base[1] * 7 * yearly_decomp, 7)
-
+    weekly = np.repeat(predictions.base[1] * 7 * yearly_decomp, 7)
     weekly.index = range(0, 371)
     predictions["weekly"] = weekly
     weekly_decomp_rep = pd.concat([weekly_decomp] * 53, ignore_index=True)
+
     predictions["daily"] = predictions.weekly * (1 / 7) * weekly_decomp_rep
 
-    # match predictions to future dataframe
+    # match predictions DataFrame to gen future DataFrame
     future = gen_future(sales_history, periods=forecast_length, freq="1D")
     future["dow"] = future.ds.dt.weekday
     future["woy"] = future.ds.dt.weekofyear
@@ -92,7 +88,7 @@ def forecast_near(
     validated_tank_history,
     forecast_freq="30min",
     forecast_length=144,
-    daily_lift_est=1000,
+    daily_lift_est=0,
 ):
 
     # less than 9 days of historical data
