@@ -21,13 +21,13 @@ def test_format_tank_empty():
     assert x is None
 
 
-def test_format_tank_two_entries(tank_input_two_entry):
-    x = validation.format_tank(tank_input_two_entry)
+def test_format_tank_two_entries(tank_two_entry_input):
+    x = validation.format_tank(tank_two_entry_input)
     assert x is None
 
 
-def test_format_tank_proper(tank_input_proper):
-    x = validation.format_tank(tank_input_proper)
+def test_format_tank_proper(tank_little_input):
+    x = validation.format_tank(tank_little_input)
     assert type(x) is pd.core.frame.DataFrame
     assert len(x['ds']) != 0
     assert len(x['y']) != 0
@@ -45,8 +45,8 @@ def test_format_sales_empty():
     assert x is None
 
 
-def test_format_sales_proper(sales_input_proper):
-    x = validation.format_sales(sales_input_proper)
+def test_format_sales_proper(sales_little_input):
+    x = validation.format_sales(sales_little_input)
     assert type(x) is pd.core.frame.DataFrame
     assert len(x['ds']) != 0
     assert len(x['y']) != 0
